@@ -37,7 +37,7 @@ class _NullSession(Session):
     def _fail(self, *args, **kwargs):
         raise RuntimeError('the session is unavailable because no secret '
                            'key was set.  Set the secret_key on the '
-                           'application to something unique and secret')
+                           'application to something unique and secret.')
     __setitem__ = __delitem__ = clear = pop = popitem = \
         update = setdefault = _fail
     del _fail
